==> haskell-clientsession-0.9.3.0-67-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-clientsession.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 clientsession
version:              0.9.3.0
visibility:           public
id:                   clientsession-0.9.3.0-F81IgejuppZIVdHDsmZ7W4
key:                  clientsession-0.9.3.0-F81IgejuppZIVdHDsmZ7W4
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Felipe Lessa <felipe.lessa@gmail.com>

stability:            stable
homepage:             http://github.com/yesodweb/clientsession/tree/master
synopsis:             Securely store session data in a client-side cookie.
description:
    Achieves security through AES-CTR encryption and
    Skein-MAC-512-256 authentication.  Uses Base64
    encoding to avoid any issues with characters.

category:             Web
abi:                  f799cf6b5ab3dd9df48cbd3353891097
exposed:              True
exposed-modules:      Web.ClientSession
hidden-modules:       System.LookupEnv
import-dirs:          /usr/lib/ghc-9.6.6/site-local/clientsession-0.9.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/clientsession-0.9.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/clientsession-0.9.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-clientsession
hs-libraries:         HSclientsession-0.9.3.0-F81IgejuppZIVdHDsmZ7W4
depends:
    base-4.18.2.1 base64-bytestring-1.2.1.0-AZbYiNuTo1lLfA6t4c9Fhh
    bytestring-0.11.5.3 cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK
    crypto-api-0.13.3-7R6mWxyWT8b203JTOR7lix
    crypton-1.0.4-8iIZddQo7Y8B1JLRcnCUbI directory-1.3.8.5
    entropy-0.4.1.11-1vtyWzOCursffXS6ZqzcH
    setenv-0.1.1.3-CVeJDG29Zk69t8Gaft7eyg
    skein-1.0.9.4-FUsFOeMAfRpB0mgagTe4Kh
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig

haddock-interfaces:
    /usr/share/doc/haskell-clientsession/html/clientsession.haddock

haddock-html:         /usr/share/doc/haskell-clientsession/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-clientsession-0.9.3.0-68-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-clientsession.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 clientsession
version:              0.9.3.0
visibility:           public
id:                   clientsession-0.9.3.0-7Qaz243uinzAxbsZKCsGvF
key:                  clientsession-0.9.3.0-7Qaz243uinzAxbsZKCsGvF
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Felipe Lessa <felipe.lessa@gmail.com>

stability:            stable
homepage:             http://github.com/yesodweb/clientsession/tree/master
synopsis:             Securely store session data in a client-side cookie.
description:
    Achieves security through AES-CTR encryption and
    Skein-MAC-512-256 authentication.  Uses Base64
    encoding to avoid any issues with characters.

category:             Web
abi:                  49cedd11aef92c9068f69ebed84df645
exposed:              True
exposed-modules:      Web.ClientSession
hidden-modules:       System.LookupEnv
import-dirs:          /usr/lib/ghc-9.6.6/site-local/clientsession-0.9.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/clientsession-0.9.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/clientsession-0.9.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-clientsession
hs-libraries:         HSclientsession-0.9.3.0-7Qaz243uinzAxbsZKCsGvF
depends:
    base-4.18.2.1 base64-bytestring-1.2.1.0-LrCtfbXf96jILPXKH7KAXZ
    bytestring-0.11.5.3 cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK
    crypto-api-0.13.3-7R6mWxyWT8b203JTOR7lix
    crypton-1.0.4-37TsNQoV8Vb5042LlXS4MC directory-1.3.8.5
    entropy-0.4.1.11-1vtyWzOCursffXS6ZqzcH
    setenv-0.1.1.3-CVeJDG29Zk69t8Gaft7eyg
    skein-1.0.9.4-FUsFOeMAfRpB0mgagTe4Kh
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig

haddock-interfaces:
    /usr/share/doc/haskell-clientsession/html/clientsession.haddock

haddock-html:         /usr/share/doc/haskell-clientsession/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
